==> ui-react-1.0.84.tgz: package/esm/BubbleChart/BubbleChart.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
const _excluded = ["tonal", "color", "names", "values", "animate", "animateTimeout", "tooltipRender", "tooltipGroupRender", "className"];
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
import React from 'react';
import { is } from '@onesy/utils';
import { classNames, style as styleMethod, useOnesyTheme } from '@onesy/style-react';
import ChartElement from '../Chart';
import LineElement from '../Line';
import TypeElement from '../Type';
import SurfaceElement from '../Surface';
import BubbleChartItemElement from '../BubbleChartItem';
import { staticClassName } from '../utils';
const useStyle = styleMethod(theme => ({
  root: {
    '& .onesy-Chart-legend-icon': {
      position: 'relative',
      background: 'none !important',
      border: '2px solid currentColor',
      '&::before': {
        content: "''",
        position: 'absolute',
        top: '0',
        left: '0',
        height: '100%',
        width: '100%',
        borderRadius: 'inherit',
        background: 'currentColor',
        opacity: '0.14'
      }
    }
  },
  append_wrapper: {
    userSelect: 'none',
    pointerEvents: 'none'
  },
  append: {
    padding: `${theme.methods.space.value(1.5, 'px')} ${theme.methods.space.value(2.5, 'px')}`,
    borderRadius: theme.methods.shape.radius.value(1.5, 'px')
  },
  append_icon: {
    width: '8px',
    height: '8px',
    borderRadius: theme.methods.shape.radius.value(40, 'px')
  }
}), {
  name: 'onesy-BubbleChart'
});
const BubbleChart = /*#__PURE__*/React.forwardRef((props_, ref) => {
  const theme = useOnesyTheme();
  const l = theme.l;
  const props = React.useMemo(() => _objectSpread(_objectSpread(_objectSpread({}, theme?.ui?.elements?.all?.props?.default), theme?.ui?.elements?.onesyBubbleChart?.props?.default), props_), [props_]);
  const Line = React.useMemo(() => theme?.elements?.Line || LineElement, [theme]);
  const Chart = React.useMemo(() => theme?.elements?.Chart || ChartElement, [theme]);
  const Type = React.useMemo(() => theme?.elements?.Type || TypeElement, [theme]);
  const Surface = React.useMemo(() => theme?.elements?.Surface || SurfaceElement, [theme]);
  const BubbleChartItem = React.useMemo(() => theme?.elements?.BubbleChartItem || BubbleChartItemElement, [theme]);
  const {
      tonal = true,
      color = 'primary',
      names,
      values,
      animate,
      animateTimeout,
      tooltipRender: tooltipRender_,
      tooltipGroupRender: tooltipGroupRender_,
      className
    } = props,
    other = _objectWithoutProperties(props, _excluded);
  const {
    classes
  } = useStyle();
  const tooltipRender = is('function', tooltipRender_) ? tooltipRender_ : values_ => {
    const {
      values: values__
    } = values_;
    return {
      element: /*#__PURE__*/React.createElement(Line, {
        tonal: tonal,
        color: color,
        elevation: 1,
        gap: 0.5,
        direction: "column",
        Component: Surface,
        className: classNames([staticClassName('BubbleChart', theme) && ['onesy-BubbleChart-append'], classes.append])
      }, /*#__PURE__*/React.createElement(Line, {
        gap: 1,
        direction: "row",
        align: "center"
      }, /*#__PURE__*/React.createElement(Type, {
        version: "b3"
      }, values__?.[3])), /*#__PURE__*/React.createElement(Line, {
        gap: 0.4,
        direction: "column"
      }, /*#__PURE__*/React.createElement(Line, {
        gap: 1,
        direction: "row",
        align: "center"
      }, /*#__PURE__*/React.createElement(Type, {
        version: "b3",
        style: {
          fontWeight: 600
        }
      }, names?.y || 'y'), /*#__PURE__*/React.createElement(Type, {
        version: "b3"
      }, values__?.[1])), /*#__PURE__*/React.createElement(Line, {
        gap: 1,
        direction: "row",
        align: "center"
      }, /*#__PURE__*/React.createElement(Type, {
        version: "b3",
        style: {
          fontWeight: 600
        }
      }, names?.x || 'x'), /*#__PURE__*/React.createElement(Type, {
        version: "b3"
      }, values__?.[0])), /*#__PURE__*/React.createElement(Line, {
        gap: 1,
        direction: "row",
        align: "center"
      }, /*#__PURE__*/React.createElement(Type, {
        version: "b3",
        style: {
          fontWeight: 600
        }
      }, names?.size || 'Size'), /*#__PURE__*/React.createElement(Type, {
        version: "b3"
      }, values__?.[2]))))
    };
  };
  const tooltipGroupRender = is('function', tooltipGroupRender_) ? tooltipGroupRender_ : (groups, groupsSorted) => {
    return /*#__PURE__*/React.createElement(Line, {
      tonal: tonal,
      color: color,
      elevation: 1,
      gap: 0.25,
      direction: "column",
      Component: Surface,
      className: classNames([staticClassName('BubbleChart', theme) && ['onesy-BubbleChart-append'], classes.append])
    }, /*#__PURE__*/React.createElement(Line, {
      gap: 1,
      direction: "column",
      style: {
        width: '100%'
      }
    }, /*#__PURE__*/React.createElement(Line, {
      gap: 1,
      direction: "row",
      align: "center"
    }, /*#__PURE__*/React.createElement(Type, {
      version: "b3",
      style: {
        fontWeight: 600
      }
    }, l('Label')), /*#__PURE__*/React.createElement(Type, {
      version: "b3",
      style: {
        fontWeight: 600
      }
    }, names?.y || 'y'), /*#__PURE__*/React.createElement(Type, {
      version: "b3",
      style: {
        fontWeight: 600
      }
    }, names?.x || 'x'), /*#__PURE__*/React.createElement(Type, {
      version: "b3",
      style: {
        fontWeight: 600
      }
    }, names?.size || l('Size'))), /*#__PURE__*/React.createElement(Line, {
      gap: 1,
      direction: "column"
    }, groupsSorted.map((group, index) => /*#__PURE__*/React.createElement(Line, {
      key: index,
      gap: 1,
      direction: "column",
      style: {
        width: '100%'
      }
    }, /*#__PURE__*/React.createElement("span", {
      className: classNames([staticClassName('BubbleChart', theme) && ['onesy-BubbleChart-append-icon'], classes.append_icon]),
      style: {
        background: !theme.palette.color[group] ? group : theme.palette.color[group][groups[group][0]?.item?.tone || 'main']
      }
    }), /*#__PURE__*/React.createElement(Line, {
      gap: 0,
      direction: "column",
      style: {
        width: '100%'
      }
    }, groups[group].map((item, index_) => /*#__PURE__*/React.createElement(Line, {
      key: index_,
      gap: 1,
      direction: "row",
      style: {
        width: '100%'
      }
    }, /*#__PURE__*/React.createElement(Type, {
      version: "b3"
    }, item?.values?.[3]), /*#__PURE__*/React.createElement(Type, {
      version: "b3"
    }, item?.values?.[1]), /*#__PURE__*/React.createElement(Type, {
      version: "b3"
    }, item?.values?.[0]), /*#__PURE__*/React.createElement(Type, {
      version: "b3"
    }, item?.values?.[2])))))))));
  };
  values.sort((a, b) => a.values?.[2] - b.values?.[2]);
  const minSize = values[0]?.values?.[2];
  const maxSize = values[values.length - 1]?.values?.[2];
  return /*#__PURE__*/React.createElement(Chart, _extends({
    ref: ref,
    tonal: tonal,
    color: color,
    values: values,
    pointsVisibility: "hidden",
    elementTooltip: true,
    tooltipRender: tooltipRender,
    tooltipGroupRender: tooltipGroupRender,
    className: classNames([staticClassName('BubbleChart', theme) && ['onesy-BubbleChart-root'], className, classes.root])
  }, other), is('array', values) && values.map((item, index) => /*#__PURE__*/React.createElement(BubbleChartItem, _extends({
    key: index,
    animate: animate,
    animateTimeout: animateTimeout,
    minSize: minSize,
    maxSize: maxSize
  }, item))));
});
BubbleChart.displayName = 'onesy-BubbleChart';
export default BubbleChart;

==> ui-react-1.1.440.tgz: package/esm/BubbleChart/BubbleChart.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
const _excluded = ["tonal", "color", "names", "values", "animate", "animateTimeout", "tooltipRender", "tooltipGroupRender", "className"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
import React from 'react';
import { is } from '@amaui/utils';
import { classNames, style as styleMethod, useAmauiTheme } from '@amaui/style-react';
import ChartElement from '../Chart';
import LineElement from '../Line';
import TypeElement from '../Type';
import SurfaceElement from '../Surface';
import BubbleChartItemElement from '../BubbleChartItem';
import { staticClassName } from '../utils';
const useStyle = styleMethod(theme => ({
  root: {
    '& .amaui-Chart-legend-icon': {
      position: 'relative',
      background: 'none !important',
      border: '2px solid currentColor',
      '&::before': {
        content: "''",
        position: 'absolute',
        top: '0',
        left: '0',
        height: '100%',
        width: '100%',
        borderRadius: 'inherit',
        background: 'currentColor',
        opacity: '0.14'
      }
    }
  },
  append_wrapper: {
    userSelect: 'none',
    pointerEvents: 'none'
  },
  append: {
    padding: `${theme.methods.space.value(1.5, 'px')} ${theme.methods.space.value(2.5, 'px')}`,
    borderRadius: theme.methods.shape.radius.value(1.5, 'px')
  },
  append_icon: {
    width: '8px',
    height: '8px',
    borderRadius: theme.methods.shape.radius.value(40, 'px')
  }
}), {
  name: 'amaui-BubbleChart'
});
const BubbleChart = /*#__PURE__*/React.forwardRef((props_, ref) => {
  const theme = useAmauiTheme();
  const props = React.useMemo(() => _objectSpread(_objectSpread(_objectSpread({}, theme?.ui?.elements?.all?.props?.default), theme?.ui?.elements?.amauiBubbleChart?.props?.default), props_), [props_]);
  const Line = React.useMemo(() => theme?.elements?.Line || LineElement, [theme]);
  const Chart = React.useMemo(() => theme?.elements?.Chart || ChartElement, [theme]);
  const Type = React.useMemo(() => theme?.elements?.Type || TypeElement, [theme]);
  const Surface = React.useMemo(() => theme?.elements?.Surface || SurfaceElement, [theme]);
  const BubbleChartItem = React.useMemo(() => theme?.elements?.BubbleChartItem || BubbleChartItemElement, [theme]);
  const {
      tonal = true,
      color = 'primary',
      names,
      values,
      animate,
      animateTimeout,
      tooltipRender: tooltipRender_,
      tooltipGroupRender: tooltipGroupRender_,
      className
    } = props,
    other = _objectWithoutProperties(props, _excluded);
  const {
    classes
  } = useStyle();
  const tooltipRender = is('function', tooltipRender_) ? tooltipRender_ : values_ => {
    const {
      values: values__
    } = values_;
    return {
      element: /*#__PURE__*/React.createElement(Line, {
        tonal: tonal,
        color: color,
        elevation: 1,
        gap: 0.5,
        direction: "column",
        Component: Surface,
        className: classNames([staticClassName('BubbleChart', theme) && ['amaui-BubbleChart-append'], classes.append])
      }, /*#__PURE__*/React.createElement(Line, {
        gap: 1,
        direction: "row",
        align: "center"
      }, /*#__PURE__*/React.createElement(Type, {
        version: "b3"
      }, values__?.[3])), /*#__PURE__*/React.createElement(Line, {
        gap: 0.4,
        direction: "column"
      }, /*#__PURE__*/React.createElement(Line, {
        gap: 1,
        direction: "row",
        align: "center"
      }, /*#__PURE__*/React.createElement(Type, {
        version: "b3",
        style: {
          fontWeight: 600
        }
      }, names?.y || 'y'), /*#__PURE__*/React.createElement(Type, {
        version: "b3"
      }, values__?.[1])), /*#__PURE__*/React.createElement(Line, {
        gap: 1,
        direction: "row",
        align: "center"
      }, /*#__PURE__*/React.createElement(Type, {
        version: "b3",
        style: {
          fontWeight: 600
        }
      }, names?.x || 'x'), /*#__PURE__*/React.createElement(Type, {
        version: "b3"
      }, values__?.[0])), /*#__PURE__*/React.createElement(Line, {
        gap: 1,
        direction: "row",
        align: "center"
      }, /*#__PURE__*/React.createElement(Type, {
        version: "b3",
        style: {
          fontWeight: 600
        }
      }, names?.size || 'Size'), /*#__PURE__*/React.createElement(Type, {
        version: "b3"
      }, values__?.[2]))))
    };
  };
  const tooltipGroupRender = is('function', tooltipGroupRender_) ? tooltipGroupRender_ : (groups, groupsSorted) => {
    return /*#__PURE__*/React.createElement(Line, {
      tonal: tonal,
      color: color,
      elevation: 1,
      gap: 0.25,
      direction: "column",
      Component: Surface,
      className: classNames([staticClassName('BubbleChart', theme) && ['amaui-BubbleChart-append'], classes.append])
    }, /*#__PURE__*/React.createElement(Line, {
      gap: 1,
      direction: "column",
      style: {
        width: '100%'
      }
    }, /*#__PURE__*/React.createElement(Line, {
      gap: 1,
      direction: "row",
      align: "center"
    }, /*#__PURE__*/React.createElement(Type, {
      version: "b3",
      style: {
        fontWeight: 600
      }
    }, "Label"), /*#__PURE__*/React.createElement(Type, {
      version: "b3",
      style: {
        fontWeight: 600
      }
    }, names?.y || 'y'), /*#__PURE__*/React.createElement(Type, {
      version: "b3",
      style: {
        fontWeight: 600
      }
    }, names?.x || 'x'), /*#__PURE__*/React.createElement(Type, {
      version: "b3",
      style: {
        fontWeight: 600
      }
    }, names?.size || 'Size')), /*#__PURE__*/React.createElement(Line, {
      gap: 1,
      direction: "column"
    }, groupsSorted.map((group, index) => /*#__PURE__*/React.createElement(Line, {
      key: index,
      gap: 1,
      direction: "column",
      style: {
        width: '100%'
      }
    }, /*#__PURE__*/React.createElement("span", {
      className: classNames([staticClassName('BubbleChart', theme) && ['amaui-BubbleChart-append-icon'], classes.append_icon]),
      style: {
        background: !theme.palette.color[group] ? group : theme.palette.color[group][groups[group][0]?.item?.tone || 'main']
      }
    }), /*#__PURE__*/React.createElement(Line, {
      gap: 0,
      direction: "column",
      style: {
        width: '100%'
      }
    }, groups[group].map((item, index_) => /*#__PURE__*/React.createElement(Line, {
      key: index_,
      gap: 1,
      direction: "row",
      style: {
        width: '100%'
      }
    }, /*#__PURE__*/React.createElement(Type, {
      version: "b3"
    }, item?.values?.[3]), /*#__PURE__*/React.createElement(Type, {
      version: "b3"
    }, item?.values?.[1]), /*#__PURE__*/React.createElement(Type, {
      version: "b3"
    }, item?.values?.[0]), /*#__PURE__*/React.createElement(Type, {
      version: "b3"
    }, item?.values?.[2])))))))));
  };
  values.sort((a, b) => a.values?.[2] - b.values?.[2]);
  const minSize = values[0]?.values?.[2];
  const maxSize = values[values.length - 1]?.values?.[2];
  return /*#__PURE__*/React.createElement(Chart, _extends({
    ref: ref,
    tonal: tonal,
    color: color,
    values: values,
    pointsVisibility: "hidden",
    elementTooltip: true,
    tooltipRender: tooltipRender,
    tooltipGroupRender: tooltipGroupRender,
    className: classNames([staticClassName('BubbleChart', theme) && ['amaui-BubbleChart-root'], className, classes.root])
  }, other), is('array', values) && values.map((item, index) => /*#__PURE__*/React.createElement(BubbleChartItem, _extends({
    key: index,
    animate: animate,
    animateTimeout: animateTimeout,
    minSize: minSize,
    maxSize: maxSize
  }, item))));
});
BubbleChart.displayName = 'amaui-BubbleChart';
export default BubbleChart;
